@@ -189,7 +189,7 @@ mspcdsty <- function(s,r,id.basis,cnt,qd.s,qd.r,xx.wt,qd.wt,prec,maxiter,alpha,s
                         cd=as.double(cd), as.integer(nn),
                         as.double(10^(lambda)*q.wk), as.integer(nxi),
                         as.double(t(cbind(r.wk,s))), as.integer(nobs),
-                        as.integer(sum(cnt)), as.integer(cnt),
+                        as.double(sum(cnt)), as.double(cnt),
                         as.double(qd.r.wk), as.integer(nqd), as.integer(nx),
                         as.double(xx.wt), as.double(qd.wt),
                         as.double(prec), as.integer(maxiter),
@@ -238,7 +238,7 @@ mspcdsty <- function(s,r,id.basis,cnt,qd.s,qd.r,xx.wt,qd.wt,prec,maxiter,alpha,s
                         cd=as.double(cd), as.integer(nn),
                         as.double(q.wk), as.integer(nxi),
                         as.double(t(cbind(r.wk0,s))), as.integer(nobs),
-                        as.integer(sum(cnt)), as.integer(cnt),
+                        as.double(sum(cnt)), as.double(cnt),
                         as.double(qd.r.wk0), as.integer(nqd), as.integer(nx),
                         as.double(xx.wt), as.double(qd.wt),
                         as.double(prec), as.integer(maxiter),
